==> crossfire-maps_1.8.0.orig.tar.gz: maps/python/guilds/guildbuy.py <==
import CFPython
import CFGuilds

whoami=CFPython.WhoAmI()
guildname=CFPython.GetEventOptions(whoami,1) # 1 is 'apply' event

def find_player(object):
    while (CFPython.GetType(object) != 1) : #1 is type 'Player'
        object = CFPython.GetPreviousObject(object)
        if not object:
            return 0
    return object
   
activator=CFPython.WhoIsActivator()
map = CFPython.GetMap(activator)

players = []
names = []

if (guildname):
    #find players by coords
    ob1=CFPython.GetObjectAt(map,33,24)
    ob2=CFPython.GetObjectAt(map,33,26)
    objects = [ob1, ob2]
    for object in objects:
        temp = find_player(object)
        if temp:
            players.append(temp)
    players.append(activator)
    
    for player in players:
        names.append(CFPython.GetName(player))
        
    if len(players) == 3:
        print '%s,%s and %s found guild %s' %(names[0], names[1], names[2], guildname)

        CFGuilds.CFGuildHouses().establish(guildname)
        #Masterize them
        for player, name in zip(players, names):
            CFGuilds.CFGuild(guildname).add_member(name, 'GuildMaster')
            guildmarker = CFPython.CreateInvisibleObjectInside(player, guildname)
            CFPython.SetName(guildmarker, guildname)
            CFPython.SetSlaying(guildmarker, 'GuildMaster')

            #teleport them
            CFPython.Teleport(player,map,int(11),int(16))
            message = "You have purchased the %s guild.  Rule it wisely.  (I would type 'save' right about now...)"
        
    else:
        message = 'To purchase a guild requires two additional persons to stand on the alcoves above.'
else:
    print 'Guild Purchase Error: %s, %s' %(guildname, activatorname)
    message = 'Guild Purchase Error, please notify a DM'
    
CFPython.Write(message,whoami)

==> crossfire-maps_1.9.1.orig.tar.gz: maps/python/guilds/guildbuy.py <==
import Crossfire
import CFGuilds

whoami=Crossfire.WhoAmI()
guildname=Crossfire.ScriptParameters() # 1 is 'apply' event

def find_player(object):
    while (object.Type != 1) : #1 is type 'Player'
        object = object.Above
        if not object:
            return 0
    return object

activator=Crossfire.WhoIsActivator()
map = activator.Map

players = []
names = []

if (guildname):
    #find players by coords
    ob1=map.GetObjectAt(33,24)
    ob2=map.GetObjectAt(33,26)
    objects = [ob1, ob2]
    for object in objects:
        temp = find_player(object)
        if temp:
            players.append(temp)
    players.append(activator)

    for player in players:
        names.append(player.Name)

    if len(players) == 3:
        print '%s,%s and %s found guild %s' %(names[0], names[1], names[2], guildname)

        CFGuilds.CFGuildHouses().establish(guildname)
        #Masterize them
        for player, name in zip(players, names):
            CFGuilds.CFGuild(guildname).add_member(name, 'GuildMaster')
            guildmarker = CFPython.CreateInvisibleObjectInside(player, guildname)
            guildmarker.Name=guildname
            guildmarker.Slaying='GuildMaster'

            #teleport them
            player.Teleport(map,int(11),int(16))
            message = "You have purchased the %s guild.  Rule it wisely.  (I would type 'save' right about now...)"

    else:
        message = 'To purchase a guild requires two additional persons to stand on the alcoves above.'
else:
    print 'Guild Purchase Error: %s, %s' %(guildname, activatorname)
    message = 'Guild Purchase Error, please notify a DM'

whoami.Write(message)
